@@ -47,7 +47,7 @@ class Config(object):
     def __init__(self, usage=None, prog=None):
         self.settings = make_settings()
         self.usage = usage
-        self.prog = prog or sys.argv[0]
+        self.prog = prog or os.path.basename(sys.argv[0])
 
     def __getattr__(self, name):
         if name not in self.settings:
@@ -67,10 +67,13 @@ class Config(object):
     def parser(self):
         kwargs = {
             "usage": self.usage,
-            "version": "%(prog)s (version " +  __version__ + ")\n",
             "prog": self.prog
         }
         parser = argparse.ArgumentParser(**kwargs)
+        parser.add_argument("-v", "--version",
+                action="version", default=argparse.SUPPRESS,
+                version="%(prog)s (version " +  __version__ + ")\n",
+                help="show program's version number and exit")
         parser.add_argument("args", nargs="*", help=argparse.SUPPRESS)
 
         keys = list(self.settings)
@@ -81,8 +84,6 @@ class Config(object):
         for k in keys:
             self.settings[k].add_option(parser)
 
-
-
         return parser
 
     @property
@@ -457,9 +458,11 @@ class WorkerClass(Setting):
     desc = """\
         The type of workers to use.
 
-        The default class (sync) should handle most 'normal' types of workloads.
-        You'll want to read http://gunicorn.org/design.html for information on
-        when you might want to choose one of the other worker classes.
+        The default class (sync) should handle most 'normal' types of
+        workloads.  You'll want to read
+        http://docs.gunicorn.org/en/latest/design.html for information
+        on when you might want to choose one of the other worker
+        classes.
 
         A string referring to one of the following bundled classes:
 
@@ -941,6 +944,82 @@ Gunicorn uses the standard Python logging module's Configuration
 file format.
 """
 
+class SyslogTo(Setting):
+    name = "syslog_addr"
+    section = "Logging"
+    cli = ["--log-syslog-to"]
+    meta = "SYSLOG_ADDR"
+    validator = validate_string
+
+    if PLATFORM == "darwin":
+        default = "unix:///var/run/syslog"
+    elif PLATFORM in ('freebsd', 'dragonfly', ):
+        default = "unix:///var/run/log"
+    elif PLATFORM == "openbsd":
+        default = "unix:///dev/log"
+    else:
+        default = "udp://localhost:514"
+
+    desc = """\
+    Address to send syslog messages
+    """
+
+
+class Syslog(Setting):
+    name = "syslog"
+    section = "Logging"
+    cli = ["--log-syslog"]
+    validator = validate_bool
+    action = 'store_true'
+    default = False
+    desc = """\
+    Log to syslog.
+    """
+
+
+class SyslogPrefix(Setting):
+    name = "syslog_prefix"
+    section = "Logging"
+    cli = ["--log-syslog-prefix"]
+    meta = "SYSLOG_PREFIX"
+    validator = validate_string
+    default = None
+    desc = """\
+    makes gunicorn use the parameter as program-name in the syslog entries.
+
+    All entries will be prefixed by gunicorn.<prefix>. By default the program
+    name is the name of the process.
+    """
+
+
+class SyslogFacility(Setting):
+    name = "syslog_facility"
+    section = "Logging"
+    cli = ["--log-syslog-facility"]
+    meta = "SYSLOG_FACILITY"
+    validator = validate_string
+    default = "user"
+    desc = """\
+    Syslog facility name
+    """
+
+
+class EnableStdioInheritance(Setting):
+    name = "enable_stdio_inheritance"
+    section = "Logging"
+    cli = ["-R", "--enable-stdio-inheritance"]
+    validator = validate_bool
+    default = False
+    action = "store_true"
+    desc = """\
+    Enable stdio inheritance
+
+    Enable inheritance for stdio file descriptors in daemon mode.
+
+    Note: To disable the python stdout buffering, you can to set the user
+    environment variable ``PYTHONUNBUFFERED`` .
+    """
+
 
 class Procname(Setting):
     name = "proc_name"
@@ -1229,51 +1308,3 @@ class CertFile(Setting):
     desc = """\
     SSL certificate file
     """
-
-
-class SyslogTo(Setting):
-    name = "syslog_addr"
-    section = "Logging"
-    cli = ["--log-syslog-to"]
-    meta = "SYSLOG_ADDR"
-    validator = validate_string
-
-    if PLATFORM == "darwin":
-        default = "unix:///var/run/syslog"
-    elif PLATFORM in ('freebsd', 'dragonfly', ):
-        default = "unix:///var/run/log"
-    elif PLATFORM == "openbsd":
-        default = "unix:///dev/log"
-    else:
-        default = "udp://localhost:514"
-
-    desc = """\
-    Address to send syslog messages
-    """
-
-
-class Syslog(Setting):
-    name = "syslog"
-    section = "Logging"
-    cli = ["--log-syslog"]
-    validator = validate_bool
-    action = 'store_true'
-    default = False
-    desc = """\
-    Log to syslog.
-    """
-
-
-class SyslogPrefix(Setting):
-    name = "syslog_prefix"
-    section = "Logging"
-    cli = ["--log-syslog-prefix"]
-    meta = "SYSLOG_PREFIX"
-    validator = validate_string
-    default = None
-    desc = """\
-    makes gunicorn use the parameter as program-name in the syslog entries.
-
-    All entries will be prefixed by gunicorn.<prefix>. By default the program
-    name is the name of the process.
-    """
